#!/bin/sh

# Build script for Jackbeat
# Author: Ejis <ejis@mailoo.org>

# Homepage: http://jackbeat.samalyse.org/


set -e


SOFTNAME=jackbeat
VERSION=0.7.6
ZENVER=66
BUILD=1

CATEGORY=extra/xap

MARCH=i686
FLAGS="-O2 -march=$MARCH -mtune=i686"

DOTNEW=1

CWD=$(pwd)

PKG=$SOFTNAME-$VERSION-$MARCH-$ZENVER.$BUILD

SOFTDIR=$CWD/$SOFTNAME-$VERSION
PKGDIR=$CWD/$PKG

PKGFILE=$PKGDIR.txz
MD5=$PKGDIR.md5
SRC=$PKGDIR.src
DEP=$PKGDIR.dep
LOG=$PKGDIR.log

SRCFILES=(
	$SOFTNAME-$VERSION.tar.gz
	$SOFTNAME.png
)

HOSTURL=http://zenwalk.pinguix.com/user-accounts/ejis/$CATEGORY/$SOFTNAME/$ZENVER
SRCURLS=(
	http://jackbeat.samalyse.org/downloads
	$HOSTURL
)

SRCLINKS=(
	${SRCURLS[0]}/${SRCFILES[0]}
	${SRCURLS[1]}/${SRCFILES[1]}
)

DOC=(
	$SOFTDIR/AUTHORS
	$SOFTDIR/ChangeLog
	$SOFTDIR/COPYING
	$SOFTDIR/INSTALL
	$SOFTDIR/NEWS
	$SOFTDIR/README
)

EXTRADEPS=(
	swh-plugins
)

LESSDEPS=(
)


# Check for source files and download them if necessary

if [ ! -f ${SRCFILES[0]} ]; then
	wget -c -t 0 -T 50 -w 0 ${SRCLINKS[0]}
fi

if [ ! -f ${SRCFILES[1]} ]; then
	wget -c -t 0 -T 50 -w 0 ${SRCLINKS[1]}
fi


# Erase the previous build files

rm -rf $SOFTDIR $PKGDIR $MD5 $SRC $DEP $LOG
mkdir -p $PKG


# Build

echo ""
echo "-----Building-----"
echo ""

tar -xvf $CWD/${SRCFILES[0]}

cd $SOFTDIR

export CFLAGS=$FLAGS
export CXXFLAGS=$FLAGS

./configure \
	--prefix=/usr \
	--localstatedir=/var \
	--sysconfdir=/etc \
	--mandir=/usr/man \
	--infodir=/usr/info

sed -i "s:-O3::g" Makefile
sed -i "s:-O3::g" src/Makefile
sed -i "s:-O3::g" src/core/Makefile
sed -i "s:-O3::g" src/stream/Makefile

make -j2
make DESTDIR=$PKGDIR install


mkdir -p $PKGDIR/usr/share/icons/hicolor/48x48/apps
mkdir $PKGDIR/usr/share/applications


cp $CWD/${SRCFILES[1]} \
	$PKGDIR/usr/share/icons/hicolor/48x48/apps/


cat << EOF > $PKGDIR/usr/share/applications/$SOFTNAME.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Jackbeat
Comment=Audio sequencer
Exec=jackbeat
Icon=jackbeat
Terminal=false
Type=Application
X-MultipleArgs=false
Categories=GTK;Audio;AudioVideo;AudioVideoEditing;Multimedia
EOF
	


# Packaging

echo ""
echo "-----Packaging-----"
echo ""

cd $PKGDIR

mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/src/$SOFTNAME-$VERSION
mkdir -p $PKGDIR/usr/doc/$SOFTNAME-$VERSION


	   #|-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc <<EOF
$SOFTNAME: $SOFTNAME - Audio sequencer
$SOFTNAME:
$SOFTNAME: Jackbeat is an audio sequencer running on Linux and Mac OS X, for
$SOFTNAME: musicians and sound artists:
$SOFTNAME: * Drummachine interface with animations for easy and playful editing
$SOFTNAME: * Built for both composition and live setups with high interactivity
$SOFTNAME: needs
$SOFTNAME: * Extremely easy to use but yet powerful by connecting with other
$SOFTNAME: applications using JACK and OSC
$SOFTNAME: * Loads and saves .jab files, Jackbeat's xml+tar open file format
$SOFTNAME: * Supports ALSA, CoreAudio, PulseAudio and JACK
EOF


# Redundent

if [ -d $PKGDIR/usr/share/doc ]; then
	mv $PKGDIR/usr/share/doc/$SOFTNAME/* $PKGDIR/usr/doc/$SOFTNAME-$VERSION/
	rm -rvf $PKGDIR/usr/share/doc
fi

if [ -d $PKGDIR/etc ]; then
	if [ $DOTNEW == 1 ]; then
		dotnewfiles=$(find $PKGDIR/etc -type f -print -exec \
			mv {} {}.new \;)
		cat << EOF > $PKGDIR/install/doinst.sh
dotnewfiles=(${dotnewfiles[@]})

for file in \${dotnewfiles[@]}; do
	if [ ! -f \$file ]; then
		mv \$file.new \$file
	fi
done
EOF
		sed -i "s:$PKGDIR/::g" $PKGDIR/install/doinst.sh
	fi
fi

find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null || true
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null || true

if [ -d $PKGDIR/usr/man ]; then
	
	( cd $PKGDIR/usr/man
		find . -type f -exec gzip -9 {} \;
		for i in $( find . -type l ) ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
	)
	
fi

if [ -d $PKGDIR/usr/info ]; then
	
	rm -f $PKGDIR/usr/info/dir
	gzip -9 $PKGDIR/usr/info/*.info*
	
fi

find . -name perllocal.pod \
	-o -name ".packlist" \
	-o -name "*.bs" \
	| xargs rm -f


cp -v $CWD/build-$SOFTNAME.sh \
	$CWD/${SRCFILES[1]} \
	$PKGDIR/usr/src/$SOFTNAME-$VERSION/

cp -rv	${DOC[@]} $PKGDIR/usr/doc/$SOFTNAME-$VERSION/


# fix permissions
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;


fakeroot /sbin/makepkg -l y -c n $PKGFILE


cd $CWD

echo 'Creating .md5 file'
md5sum $PKG.txz > $MD5

echo 'Creating .src file'
echo "$HOSTURL/build-$SOFTNAME.sh" > $SRC
for link in ${SRCLINKS[@]}; do
	echo $link >> $SRC
done

echo 'Checking for dependencies'
deps=$(depfinder $PKGFILE)

for dep in ${EXTRADEPS[@]}; do
	deps="$deps,$dep"
done

for dep in ${LESSDEPS[@]}; do
	deps=${deps/$dep/}
done

order=$(echo ${deps//,/ } | sort -d)
echo ${order// /,} > $DEP

echo "Removing build directories"
rm -rf $SOFTDIR $PKGDIR
